@@ -1,3 +1,4 @@
+{-# LANGUAGE DefaultSignatures, DeriveAnyClass, DeriveGeneric, StandaloneDeriving #-}
 {-DHUN| module defining the datatypes needed for the outer imperative flow control of the program. All configurtion information needed for single run of the program is stored here. DHUN-}
 module ImperativeState where
 import Data.Map.Strict
@@ -8,9 +9,9 @@ import UrlAnalyse
 import Control.Concurrent.MVar
 import Data.List
 import Network.URL
-
 {-DHUN| A type to for errors that might be thrown during the imperative calculation DHUN-}
-
+import Data.Serialize
+import GHC.Generics
 data MyError = DownloadError String String
              | OtherError String
              | WikiUrlParseError String
@@ -23,6 +24,19 @@ data MyError = DownloadError String String
              | ToManyOutputOptionsError
              | PaperError
 
+
+
+deriving instance Generic Network.URL.URL
+deriving instance Generic Network.URL.Host
+deriving instance Generic Network.URL.Protocol
+deriving instance Generic Network.URL.URLType
+
+deriving instance Serialize Network.URL.URL
+deriving instance Serialize Network.URL.Host
+deriving instance Serialize Network.URL.Protocol
+deriving instance Serialize Network.URL.URLType
+
+
 {-DHUN| A monad for dealing with errors DHUN-}
 
 type MyErrorMonad = Either MyError
@@ -83,38 +97,43 @@ imperativeStateZero
   = do v <- newMVar (0 :: Int)
        return
          ImperativeState{audict = [], fullUrl = fullWikiUrlZero,
-                         tmpPath = "", counter = v, loadacu = []}
+                         tmpPath = "", counter = v, loadacu = Right []}
 
 data ImperativeState = ImperativeState{audict ::
                                        [(Map String Contributor)],
                                        fullUrl :: FullWikiUrl, tmpPath :: String,
-                                       counter :: MVar Int, loadacu :: [Anything Char]}
+                                       counter :: MVar Int, loadacu :: Either [FilePath] [Anything Char]}
+
+
 
 data ImageInfo = ImageInfo{wikiFilename :: String,
                            imageNumber :: Integer, contributorUrls :: [String],
                            descriptionUrl :: URL}
-               deriving (Show, Read)
+               deriving (Show, Read, Serialize, Generic)
 
 type ImperativeMonad = ExceptT MyError (StateT ImperativeState IO)
 
 data BookMode = Yes | No
-             deriving (Show, Read, Eq)
+             deriving (Show, Read, Eq, Serialize, Generic)
 
 data RunMode = HTML BookMode
              | ExpandedTemplates BookMode 
              | StandardTemplates BookMode
              | UserTemplateFile BookMode String
-             deriving (Show, Read, Eq)
+             deriving (Show, Read, Eq, Serialize, Generic)
 
 data SourceMode = Included
                 | Excluded
-                deriving (Show, Read)
+                deriving (Show, Read, Serialize, Generic)
 
 data OutputType = PlainPDF
                 | ZipArchive
                 | EPubFile
                 | OdtFile
-                deriving (Show, Read, Eq)
+                deriving (Show, Read, Eq, Serialize, Generic)
+
+data ConvertState = NewTree String | TreeToLaTeX String String | NewLoad String
+                deriving (Show, Read, Eq,  Serialize, Generic)
 
 data FullConfig = FullConfig{headers :: Maybe String,
                              resolution :: Integer, outputFilename :: String,
@@ -122,8 +141,8 @@ data FullConfig = FullConfig{headers :: Maybe String,
                              vector :: Bool, copy :: Maybe String, mainPath :: String,
                              server :: Maybe Int, outputType :: OutputType,
                              selfTest :: Maybe (Integer, Integer), compile :: Maybe String,
-                             imgctrb :: Maybe String}
-                deriving (Show, Read)
+                             imgctrb :: Maybe String, convert:: Maybe (ConvertState)}
+                deriving (Show, Read, Serialize, Generic)
 
 fullconfigbase :: FullConfig
 fullconfigbase
@@ -131,4 +150,4 @@ fullconfigbase
                outputFilename = "", inputUrl = "", runMode = HTML No, paper = "A4",
                vector = False, copy = Nothing, mainPath = "", server = Nothing,
                outputType = PlainPDF, selfTest = Nothing, compile = Nothing,
-               imgctrb = Nothing}
+               imgctrb = Nothing, convert =Nothing}
