@@ -25,8 +25,9 @@ import MediaWikiParseTree
 import Network.URL
 import Control.Monad.Except
 import System.Process
-import Data.Serialize as S (decode)
 import HtmlParser (parseHtml)
+import Data.Serialize as S (encode, decode)
+
 
 
 notendyet ::
@@ -140,33 +141,83 @@ qIncludeAction wurl text
              _ -> return ""
   where d = (trim (takeWhile (/= '|') text))
 
-qBookIncludeAction :: FullConfig-> WikiUrl -> String ->  ImperativeMonad String
-qBookIncludeAction cfg wurl text 
-  = if isInfixOf "Vorlage" text then return ("{{" ++ text ++ "}}") else if isInfixOf "Category:" text then return ""
-      else
-         do pp <- (liftIO (print d)) >> myfun
-            case pp of
-             Just p -> do _ <- addContributors d Nothing
-                          x <- noinclude wurl ("\n\ndhunparserurl " ++ d ++ "\n\n" ++ p)
-                          st <- get
-                          systempdir <- liftIO getTemporaryDirectory
-                          tempdir <- liftIO $
-                                       createTempDirectory systempdir "MediaWiki2LaTeXParser"
-                          liftIO $ Tools.writeFile (tempdir </> "input") x
-                          _ <- liftIO $
-                                 system
-                                   ("mediawiki2latex -x " ++
-                                      (Hex.hex (show (fullconfigbase{compile = Just tempdir, runMode= runMode cfg}))))
-                          t <- liftIO $ B.readFile (tempdir </> "output")
-                          put st{loadacu = ((case S.decode t of {Right k->k;_->[]})++ (loadacu st) :: [Anything Char])}
-                          return x
-             _ -> return ""
+
+runqBookIncludeAction :: String -> ImperativeMonad ()
+runqBookIncludeAction dir
+  = do t <- liftIO $ B.readFile (dir </> "bookinput")
+       let (cfg,wurl,text,acu)=(case S.decode t of {Right k->k::(FullConfig,WikiUrl,String,Either [FilePath] [Anything Char]);_->undefined})
+       oldst<-get 
+       put oldst{loadacu=acu}
+       _ <- qBookIncludeActionbase cfg wurl text
+       st<-get 
+       liftIO $ B.writeFile (dir </> "bookoutput") (S.encode (loadacu st))
+
+
+qBookIncludeActionbase :: FullConfig-> WikiUrl -> String ->  ImperativeMonad String
+qBookIncludeActionbase cfg wurl text 
+  =  if isInfixOf "Vorlage" text then return ("{{" ++ text ++ "}}") else if isInfixOf "Category:" text then return ""
+                   else
+                     do pp <- (liftIO (print d)) >> myfun
+                        case pp of
+                         Just p -> do _ <- addContributors d Nothing
+                                      x <- noinclude wurl ("\n\ndhunparserurl " ++ d ++ "\n\n" ++ p)
+                                      st <- get
+                                      systempdir <- liftIO getTemporaryDirectory
+                                      tempdir <- liftIO $
+                                                  createTempDirectory systempdir "MediaWiki2LaTeXParser"
+                                      liftIO $ Tools.writeFile (tempdir </> "input") x
+                                      _ <- liftIO $
+                                             system
+                                               ("mediawiki2latex -x " ++
+                                                  (Hex.hex (show (fullconfigbase{compile = Just tempdir, runMode= runMode cfg}))))
+                                      case (loadacu st) of
+                                          Right base -> do t <- liftIO $ B.readFile (tempdir </> "output")
+                                                           put st{loadacu = Right ((case S.decode t of {Right k->k;_->[]})++ base :: [Anything Char])}
+                                          Left base -> put st{loadacu = Left (tempdir: base)}
+                                      return x
+                         _ -> return  ""
   where d = (trim (takeWhile (/= '|') text))
         myfun = case (runMode cfg) of 
                   HTML _ -> liftIO  (getBookpage d (wurl))
                   (ExpandedTemplates _) ->  (loadMediaWiki d wurl) >>= (return . Just)
                   _ -> (loadPlain d wurl Nothing)  >>= (return . Just)
 
+qBookIncludeAction :: FullConfig-> WikiUrl -> String ->  ImperativeMonad String
+qBookIncludeAction cfg wurl text 
+  = do sst <- get
+       case (loadacu sst) of
+        Right _ ->   if isInfixOf "Vorlage" text then return ("{{" ++ text ++ "}}") else if isInfixOf "Category:" text then return "" else
+                        do pp <- (liftIO (print d)) >> myfun
+                           case pp of
+                            Just p -> do _ <- addContributors d Nothing
+                                         x <- noinclude wurl ("\n\ndhunparserurl " ++ d ++ "\n\n" ++ p)
+                                         st <- get
+                                         systempdir <- liftIO getTemporaryDirectory
+                                         tempdir <- liftIO $ createTempDirectory systempdir "MediaWiki2LaTeXParser"
+                                         --liftIO ( Tools.writeFile (t2empdir </> "input") x)
+                                         _ <- liftIO $ system ("mediawiki2latex -x " ++   (Hex.hex (show (fullconfigbase{compile = Just tempdir, runMode= runMode cfg}))))
+                                         case (loadacu st) of
+                                          Right base -> do t <- liftIO $ B.readFile (tempdir </> "output")
+                                                           put st{loadacu = Right ((case S.decode t of {Right k->k;_->[]})++ base :: [Anything Char])}
+                                          Left base -> put st{loadacu = Left (tempdir: base)}
+                                         return x
+                            _ -> return  ""
+        Left _ ->    do systempdir <- liftIO getTemporaryDirectory
+                        tempdir <- liftIO $  createTempDirectory systempdir "MediaWiki2LaTeXBook"
+                        liftIO $ B.writeFile (tempdir </> "bookinput") (S.encode (cfg,wurl,text,loadacu sst))
+                        _ <- liftIO $ system ("mediawiki2latex -x " ++  (Hex.hex (show (fullconfigbase{convert = Just (NewLoad tempdir)}))))
+                        t <- liftIO $ B.readFile (tempdir </> "bookoutput")
+                        oldst<-get
+                        let (acu)=(case S.decode t of {Right k->k::Either [FilePath] [Anything Char];_->Right []}) 
+                        put oldst{loadacu=acu}
+                        return []
+
+                       
+  where d = (trim (takeWhile (/= '|') text))
+        myfun = case (runMode cfg) of 
+                  HTML _ -> liftIO  (getBookpage d (wurl))
+                  (ExpandedTemplates _) ->  (loadMediaWiki d wurl) >>= (return . Just)
+                  _ -> (loadPlain d wurl Nothing)  >>= (return . Just)
 
 makeUrl :: String -> String -> String -> [Char]
 makeUrl lang theFam thePage
@@ -474,7 +525,8 @@ load :: FullConfig->ImperativeMonad String
 load cfg
   = do st <- get
        case (runMode cfg) of
-           HTML Yes-> loadBook st Nothing cfg
+           HTML Yes-> do if (outputType cfg) `Data.List.elem` [ZipArchive,PlainPDF] then  put (st{loadacu=Left []}) else return ()
+                         loadBook st Nothing cfg
 
            UserTemplateFile Yes _ -> loadBook st Nothing cfg
            StandardTemplates Yes -> loadBook st Nothing cfg
