@@ -1,3 +1,4 @@
+{-# LANGUAGE DefaultSignatures, DeriveAnyClass, DeriveGeneric #-}
 {-DHUN| A module for mutable states used in the programm DHUN-}
 module MyState where
 import qualified Data.Map as Map
@@ -5,7 +6,8 @@ import Data.Map.Strict (Map)
 import Control.Monad.Trans.State (State)
 import MediaWikiParseTree
 import BaseFont
-
+import Data.Serialize
+import GHC.Generics
 {-DHUN| a type used as mutable state while processing a table. See documentation of the TableHelper module DHUN-}
 
 data TableState = TableState{rowCounter :: Int,
@@ -24,7 +26,7 @@ data TableState = TableState{rowCounter :: Int,
 
 data UrlState = UrlState{iUrlState :: Int, sUrlState :: String,
                          mUrlState :: Map String String}
-              deriving (Show, Eq, Read)
+              deriving (Show, Eq, Read, Serialize, Generic)
 
 {-DHUN| see initial value of the type UrlState DHUN-}
 
@@ -44,7 +46,7 @@ data MyState = MyState{getImages :: [String], getJ :: Int,
                        tablist :: [[String]], tabmap :: Map Int (Map Int Double),
                        fontStack :: [FontStyle], font :: Font, langu :: Maybe String,
                        forms :: Map String Int, lastChar :: Char, lastFontChanged :: Bool}
-             deriving (Show, Eq)
+             deriving (Show, Eq, Read, Serialize, Generic)
 
 {-DHUN| Renderer is the State monad using MyState as mutable state DHUN-}
 
@@ -69,22 +71,22 @@ initialState
 {-DHUN| represents an URL to a wiki (not to a page thereof), which is not a sister project of wikipedia, so not wikibooks wikisource, etc. DHUN-}
 
 data WikiBaseUrl = WikiBaseUrl{baseUrl :: String}
-                 deriving (Show, Eq)
+                 deriving (Show, Eq, Read, Serialize, Generic)
 
 {-DHUN| represents an URL to a wiki (not to a page thereof), which is a sister project of wikipedia, so wikibooks wikisource, etc. DHUN-}
 
 data WikiUrlInfo = WikiUrlInfo{language :: String,
                                wikitype :: String}
-                 deriving (Show, Eq)
+                 deriving (Show, Eq, Read, Serialize, Generic)
 
 {-DHUN| represents an URL to a wiki (not to a page thereof), which is either a sister project of wikipedia, so wikibooks wikisource, etc. or isn't a sister project of wikipedia DHUN-}
 
 data WikiUrlData = BaseUrl WikiBaseUrl
                  | UrlInfo WikiUrlInfo
-                 deriving (Show, Eq)
+                 deriving (Show, Eq, Read, Serialize, Generic)
 
 {-DHUN| represents an URL to a page on a wiki DHUN-}
 
 data WikiLinkInfo = WikiLinkInfo{urldata :: WikiUrlData,
                                  page :: String}
-                  deriving (Show, Eq)
+                  deriving (Show, Eq, Read, Serialize, Generic)
