@@ -132,7 +132,7 @@ data ProgressInfo = ProgressInfo{progress :: Double,
                                  filename :: Maybe String, startTime :: Double, barValue :: Double,
                                  lastStepTime :: Double, lastRuntime :: Double, extension :: String,
                                  failed :: Bool}
-
+  deriving (Show)
 instance NFData ProgressInfo where
         rnf a = a `seq` ()
 
@@ -289,10 +289,10 @@ fileFrame t sub
                                infoBox "Conversion Failed" $
                                  (mytext "We are sorry the converion failed, please contact our us")
 
-currentlyrunning :: Map Int ProgressInfo -> Bool
+currentlyrunning :: Map Int ProgressInfo -> Int
 currentlyrunning m
-  = not
-      (Data.List.all (\ x -> (isJust (filename x)) || (failed x))
+  = sum
+      (Data.List.map (fromEnum.((\ x -> (isNothing (filename x)) && (not (failed x)))))
          (Data.Map.Strict.elems m))
 
 wwidth2 :: [Char]
@@ -379,7 +379,7 @@ formPage m s
                           do mytext "The LaTeX source code will be compiled several times to make sure all references are resolved. The whole process will usually take about one minute." 
                              H.br
                              H.br
-                             H.div H.! A.style "font-size:large" $ H.b "There is a time limit of one hour (≈ 200 pages in PDF) on this server!"
+                             H.div H.! A.style "font-size:large" $ H.b "There is a time limit of four hours (≈ 2000 pages in PDF) on this server!"
                              H.br
                              mytext "Requests taking longer will be terminated and a \"Conversion Failed due to timeout or non zero exit code\" message will be displayed. There is no limit in the downloadable version of the software, see link on right." 
 
@@ -431,10 +431,10 @@ formPage m s
                                                      if (toString (toStrict output)) == "odt" then
                                                        ImperativeState.OdtFile else
                                                        ImperativeState.PlainPDF,
-                                               compile = Nothing, imgctrb = Nothing}
+                                               compile = Nothing, imgctrb = Nothing,  convert=Nothing}
                            yy <- newEmptyMVar
                            mm <- takeMVar m
-                           _ <- if (not (currentlyrunning mm)) then
+                           _ <- if ((currentlyrunning mm)<=3) then
                                   do _ <- forkIO $
                                             do (i, o, e, h) <- runInteractiveCommand
                                                                  ("mediawiki2latex -x " ++ act)
@@ -448,7 +448,7 @@ formPage m s
                                                               then "odt" else "pdf")
                                                zz <- forkProgressDriver o m name ss
                                                putMVar yy zz
-                                               ex h i e ((realToFrac tt) + 3600.0) m zz ss
+                                               ex h i e ((realToFrac tt) + (4*3600.0)) m zz ss
                                      return ()
                                   else
                                   do putMVar yy (-1)
