@@ -13,9 +13,9 @@ import Hex
 import Server
 import System.FilePath.Posix
 import System.Info
-import Compiler (runCompile)
+import Compiler (runCompile, runTreeToLaTeX, runNewTree)
 import Tools (replace2)
-
+import Load
 {-DHUN| Data structure to repesent a single option on the command line. DHUN-}
 
 data Flag = Verbose
@@ -194,7 +194,7 @@ header = "Usage: mediawiki2latex [OPTION...]"
 
 versionHeader :: String
 versionHeader
-  = "mediawiki2latex version 7.35\n" ++ (usageInfo header options)
+  = "mediawiki2latex version 7.36\n" ++ (usageInfo header options)
 
 {-DHUN| print the version string of mediawiki2latex. Takes the output of the compilerOpts function as input. Prints the version string if no options were given or the version command was given does noting otherwise DHUN-}
 
@@ -321,7 +321,7 @@ checkOpts cwd o
                                                       ImperativeState.copy = Nothing, mainPath = "",
                                                       server = Nothing, selfTest = Just (s, e),
                                                       outputType = PlainPDF, compile = Nothing,
-                                                      imgctrb = Nothing}
+                                                      imgctrb = Nothing, convert=Nothing}
                          _ -> Left (NotIntegerPairError featuredOption)
            _ -> case serverVal of
                     Just x -> case reads x of
@@ -335,7 +335,7 @@ checkOpts cwd o
                                                            mainPath = "", server = Just z,
                                                            outputType = PlainPDF,
                                                            selfTest = Nothing, compile = Nothing,
-                                                           imgctrb = Nothing}
+                                                           imgctrb = Nothing,  convert=Nothing}
                                   _ -> Left (NotIntegerError serverOption)
                     _ -> do hexVal <- atMostOne hexPredicate hexen o
                             case hexVal of
@@ -407,7 +407,7 @@ checkOpts cwd o
                                                         if zipVal then ZipArchive else
                                                           if epubVal then EPubFile else
                                                             if odtVal then OdtFile else PlainPDF,
-                                                      compile = Nothing, imgctrb = Nothing})
+                                                      compile = Nothing, imgctrb = Nothing, convert=Nothing})
 
 {-DHUN| main entry point of mediawiki2latex DHUN-}
 
@@ -419,10 +419,18 @@ main
        stz <- imperativeStateZero
        cwd <- getCurrentDirectory
        case (checkOpts cwd (fst o)) of
-           Right x -> case (compile x) of
-                          Just dir -> do _ <- (runStateT (runExceptT (runCompile dir x)) stz)
-                                         return ()
-                          _ -> case (imgctrb x) of
+           Right x -> case (convert x) of 
+                       Just stx -> case stx of 
+                         NewTree fn -> do _ <- (runStateT (runExceptT (runNewTree fn)) stz)
+                                          return ()
+                         TreeToLaTeX instfn fn -> do _ <- (runStateT (runExceptT (runTreeToLaTeX instfn fn)) stz)
+                                                     return ()
+                         NewLoad fn -> do _ <- (runStateT (runExceptT (runqBookIncludeAction fn)) stz)
+                                          return ()
+                       _-> case (compile x) of
+                            Just dir -> do _ <- (runStateT (runExceptT (runCompile dir x)) stz)
+                                           return ()
+                            _ -> case (imgctrb x) of
                                    Just dir -> do _ <- (runStateT (runExceptT (runCtrb dir)) stz)
                                                   return ()
                                    _ -> case (server x) of
